Name:           commissaire
Version:        0.0.1
Release:        2%{?dist}
Summary:        Simple cluster host management
License:        GPLv3+
URL:            http://github.com/projectatomic/commissaire
Source0:        https://github.com/projectatomic/%{name}/archive/%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  systemd

# For docs
BuildRequires:  python3-sphinx

# For tests
%if %{with tests}
BuildRequires:  python3-coverage
BuildRequires:  python3-mock
BuildRequires:  python3-nose
BuildRequires:  python3-flake8
%endif
BuildRequires:  pkgconfig(systemd)

Requires:  python3-setuptools
Requires:  python3-cherrypy
Requires:  python3-falcon
Requires:  python3-python-etcd
Requires:  python3-jinja2
Requires:  python3-requests
Requires:  python3-py-bcrypt

# Ansible's Python API has no stability guarantees,
# so keep the acceptable versions on a short leash.
Requires:  ansible >= 2.1.2.0
Requires:  ansible < 2.1.3.0

%description
Commissaire allows administrators of a Kubernetes, Atomic Enterprise or
OpenShift installation to perform administrative tasks without the need
to write custom scripts or manually intervene on systems.

Example tasks include:
  * rolling reboot of cluster hosts
  * upgrade software on cluster hosts
  * check the status of cluster hosts
  * scan for known vulnerabilities
  * add a new host to a cluster for container orchestration


%prep
%autosetup -n %{name}-%{version}


%build
%py3_build

# Build docs
%{__python3} setup.py build_sphinx -b text

%install
%py3_install
install -D conf/commissaire.conf %{buildroot}%{_sysconfdir}/commissaire/commissaire.conf
install -D contrib/systemd/commissaire.service %{buildroot}%{_unitdir}/commissaire.service

%check
# XXX: Issue with the coverage module.
#%{__python3} setup.py nosetests

%post
%systemd_post %{name}

%preun
%systemd_preun %{name}

%postun
%systemd_postun_with_restart %{name}



%files
%license LICENSE
%doc README.md
%doc CONTRIBUTORS
%doc MAINTAINERS
%doc build/sphinx/text/*.txt
%{_bindir}/commissaire
%{python3_sitelib}/*
%{_sysconfdir}/commissaire/commissaire.conf
%{_unitdir}/commissaire.service


%changelog
* Wed Oct  5 2016 Steve Milner <smilner@redhat.com> - 0.0.1-2
- Bumped up ansible version.

* Fri Aug 26 2016 Steve Milner <smilner@redhat.com> - 0.0.1-1
- Released 0.0.1.

* Fri Jul 29 2016 Steve Milner <smilner@redhat.com> - 0.0.1-0.6.rc3
- Bumped up ansible version.

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.1-0.5.rc3
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Tue Jun 14 2016 Steve Milner <smilner@redhat.com> - 0.0.1-0.4.rc3
- Bumped up ansible version.

* Mon Jun 06 2016 Matthew Barnes <mbarnes@redhat.com> - 0.0.1-0.3.rc3
- Move pre-release indicator ('rc3') to Release tag for compliance with
  packaging guidelines.

* Thu Jun 02 2016 Matthew Barnes <mbarnes@redhat.com> - 0.0.1rc3-2
- Switch to python3, drop RHEL hackarounds for Fedora.
- Package the correct documentation files.
- Add BR: systemd

* Tue Apr 19 2016 Matthew Barnes <mbarnes@redhat.com> - 0.0.1rc3-1
- Update for RC3.

* Mon Apr  4 2016 Steve Milner <smilner@redhat.com> - 0.0.1rc2-5
* commctl and commissaire-hash-pass are now their own package.

* Tue Mar 29 2016 Steve Milner <smilner@redhat.com> - 0.0.1rc2-4
- Added author files
- Changed from pep8 to flake8

* Thu Mar 17 2016 Steve Milner <smilner@redhat.com> - 0.0.1rc2-3
- Now using cherrypy rather than gevent.

* Tue Mar  8 2016 Steve Milner <smilner@redhat.com> - 0.0.1rc2-2
- Adding in service items.

* Tue Mar  8 2016 Steve Milner <smilner@redhat.com> - 0.0.1rc2-1
- Update for RC2.

* Mon Feb 22 2016 Matthew Barnes <mbarnes@redhat.com> - 0.0.1rc1-1
- Initial packaging.
